<template>
  <a-modal
    :title="title"
    :width="800"
    :visible="visible"
    :maskClosable="false"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭">

    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules">
        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          prop="mc"
          required
          label="名称">
          <a-input placeholder="名称" v-model="model.mc"   disabled  />
        </a-form-model-item>
        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          prop="wjms"
          required
          label="文件描述">
          <a-input placeholder="请输入文件描述" v-model="model.wjms"/>
        </a-form-model-item>

        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          label="文件上传">
          <j-upload :biz-path="getDate" v-model="fileList"></j-upload>
        </a-form-model-item>


      </a-form-model>
    </a-spin>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import {  formatNowDate } from '@/utils/util';

let validatorCodeTimer = null

export default {
  name: 'PaUploadFileModal',
  components: { JDictSelectTag },
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      fileList:[],
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      validatorRules: {

        mc: [{ required: true, message: '名称' }] ,
        fileList:  [{ required: true, message: '请上传文件' }] ,
        wjms:  [{ required: true, message: '请输入描述' }] ,
      },
      url: {
        add: '/pa/file/add',
        edit: '/pa/file/edit',
      },
      readOnly:false
    }
  },
  created() {

  },
  computed:{
    getDate(){
      return  'patent/' + new Date().Format('yyyyMMdd')
    }
  },
  methods: {
    add(item) {
      this.visible = true
      this.fileList = [];
      this.model.pid =  item.id
      this.model.mc =  item.mc
      console.info(this.model)
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
      if(record.id){
        this.readOnly=true
      }else{
        this.readOnly=false
      }
    },
    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.resetFields();
    },
    handleOk() {
      if(!this.model.pid){
        this.$message.warning('参数错误，请关闭页面重新上传！')
        return
      }
      if(this.fileList.length<1){
        this.$message.warning('至少上传一个文件！')
        return
      }
      this.model.fileList = this.fileList


      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }

          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }else{
          return false;
        }
      })
    },
    handleCancel() {
      this.close()
    },


  }
}
</script>

<style lang="less" scoped>

</style>
